@@ -8,7 +8,13 @@ try:
 except ImportError:
     from kfp.components import load_component_from_file
 
-__all__ = ["AddPyOp", "MakeCascadeFileOp", "VideoToFramesOp", "HaarFromFramesOp"]
+__all__ = [
+    "AddPyOp",
+    "MakeCascadeFileOp",
+    "VideoToFramesOp",
+    "HaarFromFramesOp",
+    "QueryDBOp",
+]
 
 AddPyOp = load_component_from_file(
     os.path.join(os.path.dirname(__file__), "add_py/component.yaml")
@@ -25,3 +31,7 @@ VideoToFramesOp = load_component_from_file(
 HaarFromFramesOp = load_component_from_file(
     os.path.join(os.path.dirname(__file__), "haar_from_frames/component.yaml")
 )
+
+QueryDBOp = load_component_from_file(
+    os.path.join(os.path.dirname(__file__), "query_db/component.yaml")
+)
